@@ -7,15 +7,19 @@
 --       A futuristic real-time strategy game.
 --          This file is part of Bos Wars.
 --
---	rush.lua		-	Define the AI.
+--      rush.lua
+--      Define the AI that has the following philosophy: 
+--      constantly train and attack with as many units as possible,
+--      no emphasis on expanding or building defenses. There could be multiple
+--      rush AIs that try to attack with different units.
 --
---	(c) Copyright 2000-2007 by Lutz Sammer and Jimmy Salmon
+--      (c) Copyright 2000-2010 by Lutz Sammer and Jimmy Salmon
 --
 --      This program is free software; you can redistribute it and/or modify
 --      it under the terms of the GNU General Public License as published by
 --      the Free Software Foundation; either version 2 of the License, or
 --      (at your option) any later version.
---  
+--
 --      This program is distributed in the hope that it will be useful,
 --      but WITHOUT ANY WARRANTY; without even the implied warranty of
 --      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -25,57 +29,43 @@
 --      along with this program; if not, write to the Free Software
 --      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 --
---	$Id: rush.lua 626 2006-11-25 18:10:03Z feb $
+--      $Id: rush.lua 626 2006-11-25 18:10:03Z feb $
 --
 
-local player
-local ai_pos
-local ai_loop_pos
+-- What we registered in AiTypes.
+local this_ai_type
 
-local function AiLoop(loop_funcs, loop_pos)
-  local ret
+-- Same as AiState[AiPlayer()].  Valid only during AiLoop.
+local state
 
-  player = AiPlayer() + 1
+local function AiLoop(funcs)
+  state = AiState[AiPlayer()]
   while (true) do
-    ret = loop_funcs[loop_pos[player]]()
+    local ret = funcs[state.loop_pos]()
     if (ret) then
-     break
+      break
     end
-    loop_pos[player] = loop_pos[player] + 1
+    state.loop_pos = state.loop_pos + 1
   end
   return true
 end
 
-function InitAiScripts_rush()
-  ai_pos      = {1, 1, 1, 1, 1, 1, 1, 1}
-  ai_loop_pos = {1, 1, 1, 1, 1, 1, 1, 1}
-  hotspotexists = nil
+local function LocalDebugPrint(text)
+  -- DebugPrint(this_ai_type.Ident .. " player " .. AiPlayer() .. " " .. text)
 end
 
-local ai_loop_funcs = {
-  function() print("Looping !"); return false end,
-  function() return AiForce(1, {"unit-assault", 20, 
-                                "unit-grenadier", 8, 
-                                "unit-bazoo", 8}) end,
-  function() return AiWaitForce(1) end,  -- wait until attack party is completed
-  function() return AiSleep(50*GameSettings.Difficulty) end,
-  function() return AiAttackWithForce(1) end,
-  function() ai_loop_pos[player] = 0; return false end,
-}
-
-local function HotSpotExists()
-  if (hotspotexists == nil) then
-    local hotspot = UnitTypeByIdent("unit-hotspot")
-    local count = Players[PlayerNumNeutral].UnitTypesCount[hotspot.Slot]
-    hotspotexists = (count ~= 0)
-  end
-  return hotspotexists
+local function InitAiScripts_rush()
+  AiState[AiPlayer()] = {
+    loop_pos = 1,
+    loop_start = nil,
+    build_order = nil,
+  }
 end
 
 local function GetBuildOrder()
   local order = {}
 
-  if (not HotSpotExists()) then
+  if (not AiHotSpotExists()) then
     order[1] = "unit-powerplant"
     order[2] = nil
   elseif (Players[AiPlayer()].MagmaStored < 300) then
@@ -94,25 +84,22 @@ local ai_funcs = {
 
   -- Build magma pump or power plant first depending on resources
   function()
-    order = GetBuildOrder()
-    return AiNeed(order[1])
+    state.build_order = GetBuildOrder()
+    return AiNeed(state.build_order[1])
   end,
   function()
-    order = GetBuildOrder()
-    return AiWait(order[1])
+    return AiWait(state.build_order[1])
   end,
   function()
-    order = GetBuildOrder()
-    if (order[2] ~= nil) then
-      return AiNeed(order[2])
+    if (state.build_order[2] ~= nil) then
+      return AiNeed(state.build_order[2])
     else
       return false
     end
   end,
   function()
-    order = GetBuildOrder()
-    if (order[2] ~= nil) then
-      return AiWait(order[2])
+    if (state.build_order[2] ~= nil) then
+      return AiWait(state.build_order[2])
     else
       return false
     end
@@ -148,13 +135,37 @@ local ai_funcs = {
   function() return AiWaitForce(1) end, 
   function() return AiAttackWithForce(1) end,
 
-  function() return AiLoop(ai_loop_funcs, ai_loop_pos) end,
+  -- ============================================================
+
+  function() 
+    LocalDebugPrint("is starting loop.");
+    state.loop_start = state.loop_pos;
+    return false
+  end,
+
+  function() return AiForce(1, {"unit-assault", 20, 
+                                "unit-grenadier", 8, 
+                                "unit-bazoo", 8}) end,
+  function() return AiWaitForce(1) end,  -- wait until attack party is completed
+  function() return AiSleep(50*GameSettings.Difficulty) end,
+  function() return AiAttackWithForce(1) end,
+
+  function()
+    LocalDebugPrint("Reached the end of AI script and will loop");
+    state.loop_pos = state.loop_start - 1; -- AiLoop will immediately increment it.
+    return false
+  end,
 }
 
-function AiRush()
---    print(AiPlayer() .. " position ".. ai_pos[AiPlayer() + 1]);
-    return AiLoop(ai_funcs, ai_pos)
+local function AiRush()
+  LocalDebugPrint("Script position " .. AiState[AiPlayer()].loop_pos);
+  return AiLoop(ai_funcs)
 end
 
-RegisterAi("rush", "rush", AiRush, InitAiScripts_rush)
-
+this_ai_type = {
+  Ident = "ai-rush",
+  Name = _("Rush"),
+  Init = InitAiScripts_rush,
+  EachSecond = AiRush,
+}
+DefineAiType(this_ai_type)
