@@ -32,18 +32,22 @@ function RunBriefingMenu(objectivestext, briefingtext, briefingsound, background
   local b
   local channel = nil
 
-  if objectivestext == nil then
-    SetObjectives(default_objective)
-    return
+  if (objectivestext == nil) then
+    objectivestext = default_objectives
+  end
+  SetObjectives(objectivestext)
+
+  local objText = ""
+  for i,f in ipairs(objectivestext) do
+    objText = objText .. f .. "\n"
   end
 
-  SetObjectives(objectivestext)
   menu = BosMenu(_("Briefing"), background)
   local text = briefingtext .. 
       "\n\n" ..
       _("Objectives:") ..
       "         \n" ..
-      objectivestext
+      objText
   local t= MultiLineLabel(text)
   t:setFont(Fonts["large"])
   t:setAlignment(MultiLineLabel.LEFT)
@@ -59,12 +63,17 @@ function RunBriefingMenu(objectivestext, briefingtext, briefingsound, background
       if (channel ~= nil) then StopChannel(channel) end
       menu:stop()
     end)
+  menu:addButton(_("Cancel (~<Esc~>)"), Video.Width / 2 - 100, Video.Height - 65,
+    function()
+      if (channel ~= nil) then StopChannel(channel) end
+      menu:stop(1)
+    end)
 
   if (briefingsound ~= nil) then
     channel = PlaySoundFile(briefingsound, function() channel = nil end)
   end
 
-  menu:run()
+  return menu:run()
 end
 
 function AddCampaignMessage(when, text)
@@ -91,13 +100,16 @@ function AddCampaignFinalAssault(when, text)
 end
 
 
-function CreateMapStep(map, objectivestext, briefingtext, briefingsound)
-   function RunCampaignMap()
-     RunBriefingMenu(objectivestext, briefingtext, briefingsound)
-     Load(map) -- Needed to force the load of the presentation
-     RunMap(map, objectivestext) 
-   end
-   return RunCampaignMap
+function CreateMapStep(map, objectivestext, briefingtext, briefingsound, briefingbackground)
+  function RunCampaignMap()
+    if (RunBriefingMenu(objectivestext, briefingtext, briefingsound, briefingbackground) ~= 0) then
+      GameResult = GameQuitToMenu
+      return
+    end
+    Load(map) -- Needed to force the load of the presentation
+    RunMap(map, objectivestext) 
+  end
+  return RunCampaignMap
 end
 
 
@@ -133,12 +145,12 @@ function RunCampaignsMenu(s)
   local browser = menu:addBrowser("campaigns/", lister,
                                  Video.Width / 2 - 150, 100, 300, 200)
   function startgamebutton(s)
-    print("Starting campaign")
+    DebugPrint("Starting campaign")
     position = nil
     RunCampaign("campaigns/" .. browser:getSelectedItem() .. "/campaign.lua")
     menu:stop()
   end
-  menu:addButton(_("~!Main Menu"), Video.Width / 2 - 250, Video.Height - 100,
+  menu:addButton(_("Main Menu (~<Esc~>)"), Video.Width / 2 - 250, Video.Height - 100,
                  function() menu:stop() end)
   menu:addButton(_("~!Start"), Video.Width / 2 + 50 ,  Video.Height - 100,
                  startgamebutton)
