@@ -109,7 +109,7 @@ function RunSaveMenu()
       menu:stop()
     end)
 
-  menu:addSmallButton(_("~!Cancel"), 16 + 12 + 106, 248,
+  menu:addSmallButton(_("Cancel (~<Esc~>)"), 16 + 12 + 106, 248,
     function() menu:stop() end)
 
   menu:run(false)
@@ -301,7 +301,7 @@ function RunDiplomacyMenu()
       end
       menu:stop()
     end)
-  menu:addSmallButton(_("~!Cancel"), 195, 384 - 40, function() menu:stop() end)
+  menu:addSmallButton(_("Cancel (~<Esc~>)"), 195, 384 - 40, function() menu:stop() end)
 
   menu:run(false)
 end
@@ -413,7 +413,7 @@ function InitKeystrokes(keystrokes)
   table.insert(keystrokes, {_("Shift-#"), _("- add to group")})
   table.insert(keystrokes, {_("Alt-#"), _("- add to alternate group")})
   table.insert(keystrokes, {_("F2-F4"), _("- recall map position")})
-  table.insert(keystrokes, {_("Shift F2-F4"), _("- save map postition")})
+  table.insert(keystrokes, {_("Shift F2-F4"), _("- save map position")})
   table.insert(keystrokes, {_("F5"), _("- game options")})
   table.insert(keystrokes, {_("F7"), _("- sound options")})
   table.insert(keystrokes, {_("F8"), _("- speed options")})
@@ -554,7 +554,12 @@ function RunObjectivesMenu()
   l:setLineWidth(356)
   menu:add(l, 14, 36)
 
-  l:setCaption(GetObjectives())
+  local objs = GetObjectives()
+  local objText = ""
+  for i,f in ipairs(objs) do
+    objText = objText .. f .. "\n"
+  end
+  l:setCaption(objText)
 
   menu:addButton(_("~!OK"), 80, 256 - 40,
     function() menu:stop() end)
