@@ -1,6 +1,9 @@
 
-function patchType(name, file, tileWidth, tileHeight, flags)
-  return Map.PatchManager:newPatchType(name, file, tileWidth, tileHeight, flags)
+function patchType(name, file, tileWidth, tileHeight, flags, theme)
+  if (theme == nil) then
+    theme = ""
+  end
+  return Map.PatchManager:newPatchType(name, file, tileWidth, tileHeight, flags, theme)
 end
 
 function patch(name, x, y)
@@ -12,7 +15,7 @@ function LoadPatches(path)
   local list = ListFilesInDirectory(path)
   for k,v in ipairs(list) do
     if (string.find(v, ".lua$")) then
-      print("Loading patch: " .. v)
+      DebugPrint("Loading patch: " .. v)
       Load(path .. v)
     end
   end
