@@ -69,7 +69,6 @@ DefineUnitType("buggy_destroyed", {
     Shadow = {"file", "units/buggy/unit_buggy_s.png", "size", {64, 64}},
     Animations = "animations-dead_buggy",
     Icon = "icon-cancel",
-    Speed = 0,
     HitPoints = 999,
     DrawLevel = 10,
     TileSize = {1, 1},
@@ -95,7 +94,6 @@ DefineUnitType("unit-buggy", {
     EnergyValue = 2000,
     MagmaValue = 500,
     RepairHp = 1,
-    Speed = 20,
     HitPoints = 40,
     DrawLevel = 25,
     TileSize = {1, 1},
@@ -117,7 +115,6 @@ DefineUnitType("unit-buggy", {
     CanAttack = true,
     CanTargetLand = true,
     RightMouseAction = "attack",
-    LandUnit = true,
     SelectableByRectangle = true,
     VisibleUnderFog = true,
     Sounds = {
