@@ -70,7 +70,6 @@ DefineUnitType("unit-gturret", {
     MagmaValue = 500,
     RepairHp = 2,
     Construction = "construction-gturret",
-    Speed = 0,
     HitPoints = 160,
     DrawLevel = 25,
     TileSize = {2, 2},
@@ -91,6 +90,7 @@ DefineUnitType("unit-gturret", {
     CanAttack = true,
     CanTargetLand = true,
     CanTargetAir = true,
+    CanTargetSea = true,
     NumDirections = 8,
     Corpse = "build-dead-gturret",
     Type = "land",
@@ -120,7 +120,6 @@ DefineUnitType("build-dead-gturret", {
     Image = {"file", GetCurrentLuaPath().."/gturret_c.png", "size", {96, 96}},
     Animations = "animations-dead-gturret",
     Icon = "icon-cancel",
-    Speed = 0,
     HitPoints = 999,
     DrawLevel = 10,
     TileSize = {2, 2},
