@@ -69,7 +69,6 @@ DefineUnitType("unit-nukepowerplant", {
     EnergyProductionRate = 46,
     RepairHp = 2,
     Construction = "construction-nukepowerplant",
-    Speed = 0,
     HitPoints = 350,
     DrawLevel = 25,
     TileSize = {7, 5},
@@ -86,7 +85,6 @@ DefineUnitType("unit-nukepowerplant", {
     Corpse = "build-dead-nukepowerplant",
     Type = "land",
     Building = true,
-    BuilderOutside = true,
     VisibleUnderFog = true,
     CanHarvestFrom = true,
     Sounds = {
@@ -107,7 +105,6 @@ DefineUnitType("build-dead-nukepowerplant", {
     Image = {"file", GetCurrentLuaPath().."/nukeplant_c.png", "size", {256, 256}},
     Animations = "animations-dead-nukepowerplant",
     Icon = "icon-cancel",
-    Speed = 0,
     HitPoints = 999,
     DrawLevel = 10,
     TileSize = {7, 5},
