@@ -43,7 +43,6 @@ DefineUnitType("unit-tree03", {
     Icon = "icon-tree",
     Construction = "construction-tree",
     EnergyValue = 5000,
-    Speed = 0,
     HitPoints = 50,
     DrawLevel = 25,
     TileSize = {1, 1},
@@ -61,7 +60,6 @@ DefineUnitType("unit-tree03", {
     Corpse = "unit-destroyed-1x1-place",
     Type = "land",
     Building = true,
-    BuilderOutside = true,
     VisibleUnderFog = true,
     NumDirections = 1,
     CanHarvestFrom = true,
